@@ -18,7 +18,7 @@ pub fn format_document(
 pub fn get_format_text_edits(text: Arc<str>, options: FormattingOptions) -> Option<Vec<TextEdit>> {
     // we only format if code is correct
 
-    match get_formatted_data(text.clone(), options) {
+    match get_formatted_data(text.clone(), options, None) {
         Ok((num_of_lines, formatted_text)) => {
             let text_lines_count = text.split('\n').count();
             let line_end = std::cmp::max(num_of_lines, text_lines_count) as u32;
